@@ -827,7 +827,7 @@ public:
 	USHORT		RESTORE_format;
 	ULONG		mvol_io_buffer_size;
 	ULONG		mvol_actual_buffer_size;
-	UINT64		mvol_cumul_count;
+	FB_UINT64	mvol_cumul_count;
 	UCHAR*		mvol_io_ptr;
 	int			mvol_io_cnt;
 	UCHAR*		mvol_io_buffer;
