@@ -86,6 +86,23 @@ static void make_parameter_names(dsql_par*, const dsql_nod*);
 
 static const char* db_key_name = "DB_KEY";
 
+dsql_nod* MAKE_const_slong(SLONG value)
+{
+	tsql* tdsql = DSQL_get_thread_data();
+
+	dsql_nod* node = FB_NEW_RPT(*tdsql->getDefaultPool(), 1) dsql_nod;
+	node->nod_type = nod_constant;
+	node->nod_desc.dsc_dtype = dtype_long;
+	node->nod_desc.dsc_length = sizeof(SLONG);
+	node->nod_desc.dsc_scale = 0;
+	node->nod_desc.dsc_sub_type = 0;
+	node->nod_desc.dsc_address = (UCHAR*) node->nod_arg;
+
+	*((SLONG *) (node->nod_desc.dsc_address)) = value;
+
+	return node;
+}
+
 
 /**
   
@@ -109,15 +126,15 @@ dsql_nod* MAKE_constant(dsql_str* constant, dsql_constant_type numeric_flag)
 
 	switch (numeric_flag)
 	{
-	case CONSTANT_SLONG:
+/*	case CONSTANT_SLONG:
 		node->nod_desc.dsc_dtype = dtype_long;
 		node->nod_desc.dsc_length = sizeof(SLONG);
 		node->nod_desc.dsc_scale = 0;
 		node->nod_desc.dsc_sub_type = 0;
 		node->nod_desc.dsc_address = (UCHAR*) node->nod_arg;
-		node->nod_arg[0] = (dsql_nod*) constant;
+		*((SLONG *) (node->nod_desc.dsc_address)) = (SLONG) (IPTR) constant;
 		break;
-
+*/
 	case CONSTANT_DOUBLE:
 		DEV_BLKCHK(constant, dsql_type_str);
 
@@ -159,7 +176,7 @@ dsql_nod* MAKE_constant(dsql_str* constant, dsql_constant_type numeric_flag)
 			   only if preceded by a '-', but that issue is handled in GEN_expr,
 			   and need not be addressed here. */
 
-			UINT64 value = 0;
+			FB_UINT64 value = 0;
 			const char* p = constant->str_data;
 
 			while (isdigit(*p))
@@ -171,7 +188,7 @@ dsql_nod* MAKE_constant(dsql_str* constant, dsql_constant_type numeric_flag)
 				}
 			}
 
-			*(UINT64 *) (node->nod_desc.dsc_address) = value;
+			*(FB_UINT64 *) (node->nod_desc.dsc_address) = value;
 			break;
 		}
 
@@ -496,7 +513,7 @@ void MAKE_desc(dsql_req* request, dsc* desc, dsql_nod* node, dsql_nod* null_repl
 			{
 				// We have a constant passed as length, so
 				// use the real length
-				length = UTLD_char_length_to_byte_length(*(SLONG *) for_node->nod_desc.dsc_address, maxBytesPerChar);
+				length = UTLD_char_length_to_byte_length(for_node->getSlong(), maxBytesPerChar);
 
 				if (length < 0 || length > MAX_COLUMN_SIZE - sizeof(USHORT))
 					length = UTLD_char_length_to_byte_length(MAX_COLUMN_SIZE - sizeof(USHORT), maxBytesPerChar);
@@ -2042,11 +2059,11 @@ dsql_str* MAKE_tagged_string(const char* strvar, size_t length, const char* char
  **/
 dsql_nod* MAKE_trigger_type(dsql_nod* prefix_node, dsql_nod* suffix_node)
 {
-	const long prefix = (long) prefix_node->nod_arg[0];
-	const long suffix = (long) suffix_node->nod_arg[0];
+	const SLONG prefix = prefix_node->getSlong();
+	const SLONG suffix = suffix_node->getSlong();
 	delete prefix_node;
 	delete suffix_node;
-	return MAKE_constant((dsql_str*) (prefix + suffix - 1), CONSTANT_SLONG);
+	return MAKE_const_slong(prefix + suffix - 1);
 }
 
 
@@ -2316,8 +2333,7 @@ static void make_parameter_names(dsql_par* parameter, const dsql_nod* item)
 		break;
 	case nod_strlen:
 		{
- 		const ULONG length_type =
-			*(SLONG*)item->nod_arg[e_strlen_type]->nod_desc.dsc_address;
+ 		const ULONG length_type = item->nod_arg[e_strlen_type]->getSlong();
 
 		switch (length_type)
 		{
