@@ -136,6 +136,7 @@
 
 #ifdef sparc
 #define IMPLEMENTATION  isc_info_db_impl_linux_sparc /* 65  */
+#define RISC_ALIGNMENT
 #endif /* sparc */
 
 #define MEMMOVE(from, to, length)		memmove ((void *)to, (void *)from, (size_t) length)
@@ -289,7 +290,7 @@ static inline int sinixz_sigaction(int sig, const struct sinixz_sigaction *act,
 #define IEEE
 #define QUADCONST(n) (n##LL)
 #define QUADFORMAT "q"
-#define MAP_ANNON
+#define MAP_ANON
 
 #define MEMMOVE(from, to, length)		memmove ((void *)to, (void *)from, (size_t)length)
 #define MOVE_FAST(from, to, length)	memcpy (to, from, (int) (length))
@@ -437,7 +438,7 @@ static inline int sinixz_sigaction(int sig, const struct sinixz_sigaction *act,
 
 /* The following define is the prefix to go in front of a "d" or "u"
    format item in a printf() format string, to indicate that the argument
-   is an SINT64 or UINT64. */
+   is an SINT64 or FB_UINT64. */
 #define QUADFORMAT "ll"
 /* The following macro creates a quad-sized constant, possibly one
    which is too large to fit in a long int. */
@@ -457,6 +458,7 @@ static inline int sinixz_sigaction(int sig, const struct sinixz_sigaction *act,
 //#define DOUBLE_ALIGN    8
 
 #define IMPLEMENTATION  isc_info_db_impl_isc_sun4 /* 30 */
+#define RISC_ALIGNMENT
 #else /* sparc */
 
 #ifdef i386
@@ -479,11 +481,7 @@ static inline int sinixz_sigaction(int sig, const struct sinixz_sigaction *act,
 * HP/UX platforms 
 *****************************************************/
 
-#if (defined(hpux) || defined(HPUX))
-
-#ifndef hpux
-#define hpux
-#endif
+#ifdef HPUX
 
 //#define KILLER_SIGNALS
 #define UNIX
@@ -501,7 +499,7 @@ static inline int sinixz_sigaction(int sig, const struct sinixz_sigaction *act,
 
 /* The following define is the prefix to go in front of a "d" or "u"
    format item in a printf() format string, to indicate that the argument
-   is an SINT64 or UINT64. */
+   is an SINT64 or FB_UINT64. */
 #define QUADFORMAT "ll"
 /* The following macro creates a quad-sized constant, possibly one
    which is too large to fit in a long int. */
@@ -512,7 +510,9 @@ static inline int sinixz_sigaction(int sig, const struct sinixz_sigaction *act,
 #define MOVE_FASTER(from, to, length)     memcpy (to, from, (int) (length))
 #define MOVE_CLEAR(to, length)           memset (to, 0, (int) (length))
 
-#endif /* hpux */
+#define RISC_ALIGNMENT
+
+#endif /* HPUX */
 
 
 /*****************************************************
@@ -609,12 +609,12 @@ typedef unsigned int64 UATOM;
 #define LINEFORMAT "d"
 
 typedef __int64 SINT64;
-typedef unsigned __int64 UINT64;
+typedef unsigned __int64 FB_UINT64;
 #define INT64_DEFINED
 
 /* The following define is the prefix to go in front of a "d" or "u"
    format item in a printf() format string, to indicate that the argument
-   is an SINT64 or UINT64. */
+   is an SINT64 or FB_UINT64. */
 #define QUADFORMAT "I64"
 /* The following macro creates a quad-sized constant, possibly one
    which is too large to fit in a long int.  The Microsoft compiler does
@@ -792,7 +792,7 @@ typedef unsigned __int64 UINT64;
 
 #ifndef INT64_DEFINED			/* 64 bit */
 typedef long long int SINT64;
-typedef unsigned long long int UINT64;
+typedef unsigned long long int FB_UINT64;
 #else
 #undef INT64_DEFINED
 #endif
@@ -869,7 +869,7 @@ struct ISC_TIMESTAMP
 #define MAX_SLONG		0x7FFFFFFF
 #define MIN_SLONG		(-MAX_SLONG - 1)
 
-#define MAX_UINT64              ((UINT64) QUADCONST(0xFFFFFFFFFFFFFFFF))
+#define MAX_UINT64              ((FB_UINT64) QUADCONST(0xFFFFFFFFFFFFFFFF))
 #define MIN_UINT64              QUADCONST(0x0000000000000000)
 
 #define MAX_SINT64              QUADCONST(0x7FFFFFFFFFFFFFFF)
