@@ -3486,7 +3486,7 @@ void gds__cleanup(void)
 
 	CLEAN clean;
 
-	while (clean = cleanup_handlers) {
+	while ( (clean = cleanup_handlers) ) {
 		cleanup_handlers = clean->clean_next;
 		FPTR_VOID_PTR routine = clean->clean_routine;
 		void* arg = clean->clean_arg;
@@ -3500,9 +3500,6 @@ void gds__cleanup(void)
 		(*routine)(arg);
 	}
 
-#ifdef V4_THREADING
-/* V4_DESTROY; */
-#endif
 	initialized = false;
 }
 
@@ -3567,10 +3564,10 @@ static void init(void)
 #endif /* SUPERSERVER */
 #endif /* UNIX */
 
-	atexit(gds__cleanup);
-
 	initialized = true;
 
+	atexit(gds__cleanup);
+
 	gdsPrefixInit();
 
 #ifndef REQUESTER
