@@ -145,7 +145,7 @@ const char* MTAB		= _PATH_MNTTAB;
 
 #if   defined(_PATH_MOUNTED)
 const char* MTAB		= _PATH_MOUNTED;
-#elif defined(hpux)
+#elif defined(HPUX)
 const char* MTAB		= "/etc/mnttab";
 #elif defined(SOLARIS)
 const char* MTAB		= "/etc/mnttab";
@@ -257,7 +257,7 @@ static void share_name_from_unc(tstring&, LPREMOTE_NAME_INFO);
 static bool get_full_path(const tstring&, tstring&);
 #endif
 
-#ifdef hpux
+#ifdef HPUX
 #if !(defined HP10 || defined HP11)
 static bool get_server(tstring&, tstring&);
 #endif
@@ -349,8 +349,7 @@ bool ISC_analyze_nfs(tstring& expanded_filename, tstring& node_name)
 		expanded_filename.replace(0, len, max_path);
 		node_name = max_node;
 	}
-// RITTER - added HP11 to the pre-processor condition below
-#if defined(hpux) && (!(defined HP10 || defined HP11))
+#if defined(HPUX) && (!(defined HP10 || defined HP11))
 	else
 	{
 		flag = get_server(expanded_filename, node_name);
@@ -1652,8 +1651,8 @@ bool Mnt::get()
 		return false;
 	}
 
-	const char * start = this->mnt_info[this->mnt_i].f_mntfromname;
-	const char * iflag = strchr(this->mnt_info[this->mnt_i].f_mntfromname, ':');
+	const char* start = this->mnt_info[this->mnt_i].f_mntfromname;
+	const char* iflag = strchr(this->mnt_info[this->mnt_i].f_mntfromname, ':');
 
 	if (iflag) {
 		node = tstring(start, size_t(iflag - start));
@@ -1736,8 +1735,7 @@ bool Mnt::get()
 }
 #endif // GET_MOUNTS
 
-#ifdef hpux
-/* RITTER - added HP11 to the pre-processor condition below */
+#ifdef HPUX
 #if !(defined HP10 || defined HP11)
 static bool get_server(tstring&, tstring& node_name)
 {
@@ -1770,7 +1768,7 @@ static bool get_server(tstring&, tstring& node_name)
 	return true;
 }
 #endif
-#endif // hpux
+#endif // HPUX
 #endif // NO_NFS
 } // anonymous namespace
 
