@@ -130,7 +130,11 @@ using namespace Jrd;
 #define MASK		0666
 #endif
 
-static jrd_file* seek_file(jrd_file*, BufferDesc*, UINT64 *, ISC_STATUS *);
+#define FCNTL_BROKEN
+// please undefine FCNTL_BROKEN for operating systems,
+// that can successfully change BOTH O_DIRECT and O_SYNC using fcntl()
+
+static jrd_file* seek_file(jrd_file*, BufferDesc*, FB_UINT64 *, ISC_STATUS *);
 static jrd_file* setup_file(Database*, const Firebird::PathName&, int);
 static bool unix_error(TEXT*, jrd_file*, ISC_STATUS, ISC_STATUS*);
 #if defined PREAD_PWRITE && !(defined HAVE_PREAD && defined HAVE_PWRITE)
@@ -138,17 +142,11 @@ static SLONG pread(int, SCHAR *, SLONG, SLONG);
 static SLONG pwrite(int, SCHAR *, SLONG, SLONG);
 #endif
 #ifdef SUPPORT_RAW_DEVICES
-static bool raw_devices_check_file (const Firebird::PathName&);
 static bool raw_devices_validate_database (int, const Firebird::PathName&);
 static int  raw_devices_unlink_database (const Firebird::PathName&);
 #endif
-
-#ifdef hpux
-union fcntlun {
-	int val;
-	struct flock *lockdes;
-};
-#endif
+static int openFile(const char*, bool, bool);
+static bool maybe_close_file(int&);
 
 
 int PIO_add_file(Database* dbb, jrd_file* main_file, const Firebird::PathName& file_name, SLONG start)
@@ -234,7 +232,7 @@ int PIO_connection(const Firebird::PathName& file_name)
 }
 
 
-jrd_file* PIO_create(Database* dbb, const Firebird::PathName& string, bool overwrite, bool share_delete)
+jrd_file* PIO_create(Database* dbb, const Firebird::PathName& file_name, bool overwrite, bool share_delete)
 {
 /**************************************
  *
@@ -249,15 +247,13 @@ jrd_file* PIO_create(Database* dbb, const Firebird::PathName& string, bool overw
  *	have been locked before entry.
  *
  **************************************/
-	const TEXT* file_name = string.c_str();
-
 #ifdef SUPERSERVER_V2
 	const int flag =
 		SYNC | O_RDWR | O_CREAT | (overwrite ? O_TRUNC : O_EXCL) | O_BINARY;
 #else
 #ifdef SUPPORT_RAW_DEVICES
 	const int flag = O_RDWR |
-			(raw_devices_check_file(file_name) ? 0 : O_CREAT) |
+			(PIO_on_raw_device(file_name) ? 0 : O_CREAT) |
 			(overwrite ? O_TRUNC : O_EXCL) |
 			O_BINARY;
 #else
@@ -265,18 +261,18 @@ jrd_file* PIO_create(Database* dbb, const Firebird::PathName& string, bool overw
 #endif
 #endif
 
-	const int desc = open(file_name, flag, MASK);
+	const int desc = open(file_name.c_str(), flag, MASK);
 	if (desc == -1) 
 	{
 		ERR_post(isc_io_error,
 				 isc_arg_string, "open O_CREAT",
-				 isc_arg_cstring, string.length(), ERR_cstring(string),
+				 isc_arg_cstring, file_name.length(), ERR_string(file_name),
 				 isc_arg_gds, isc_io_create_err, isc_arg_unix, errno, 0);
 	}
 
 /* File open succeeded.  Now expand the file name. */
 
-	Firebird::PathName expanded_name(string);
+	Firebird::PathName expanded_name(file_name);
 	ISC_expand_filename(expanded_name, false);
 	jrd_file* file;
 	try 
@@ -339,7 +335,65 @@ void PIO_flush(jrd_file* main_file)
 }
 
 
-void PIO_force_write(jrd_file* file, bool flag)
+static int openFile(const char* name, bool forcedWrites, bool readOnly)
+{
+/**************************************
+ *
+ *	o p e n F i l e
+ *
+ **************************************
+ *
+ * Functional description
+ *	Open a file with appropriate flags.
+ *
+ **************************************/
+
+	int flag = O_BINARY | (readOnly ? O_RDONLY : O_RDWR);
+#ifdef SUPERSERVER_V2
+	flag |= SYNC;
+	// what to do with O_DIRECT here ?
+#else
+	if (forcedWrites)
+		flag |= SYNC;
+#endif
+
+	for (int i = 0; i < IO_RETRY; i++)
+	{
+		int desc = open(name, flag);
+		if (desc != -1)
+			return desc;
+		if (!SYSCALL_INTERRUPTED(errno))
+			break;
+	}
+
+	return -1;
+}
+
+
+static bool maybe_close_file(int& desc)
+{
+/**************************************
+ *
+ * M a y b e C l o s e F i l e
+ *
+ **************************************
+ *
+ * Functional description
+ * If the file is open, close it.
+ *
+ **************************************/
+
+	if (desc >= 0)
+	{
+		close(desc);
+		desc = -1;
+		return true;
+	}
+	return false;
+}
+
+
+void PIO_force_write(jrd_file* file, bool forcedWrites)
 {
 /**************************************
  *
@@ -351,38 +405,38 @@ void PIO_force_write(jrd_file* file, bool flag)
  *	Set (or clear) force write, if possible, for the database.
  *
  **************************************/
-#ifdef hpux
-	union fcntlun control;
-#else
-	int control;
-#endif
 
-/* Since all SUPERSERVER_V2 database and shadow I/O is synchronous, this
-   is a no-op. */
+// Since all SUPERSERVER_V2 database and shadow I/O is synchronous, this is a no-op. 
 
 #ifndef SUPERSERVER_V2
-#ifdef hpux
-	control.val = (flag) ? SYNC : NULL;
-#else
-	control = (flag) ? SYNC : 0;
-#endif
+	const bool oldForce = (file->fil_flags & FIL_force_write) != 0;
 
-	if (fcntl(file->fil_desc, F_SETFL, control) == -1)
+	if (forcedWrites != oldForce)
 	{
-		ERR_post(isc_io_error,
-				 isc_arg_string, "fcntl SYNC",
-				 isc_arg_cstring, file->fil_length,
-				 ERR_string(file->fil_string, file->fil_length), isc_arg_gds,
-				 isc_io_access_err, isc_arg_unix, errno, 0);
-	}
-	else 
-	{
-		if (flag) {
-			file->fil_flags |= (FIL_force_write | FIL_force_write_init);
+		const int control = forcedWrites ? SYNC : 0;
+
+#ifndef FCNTL_BROKEN
+		if (fcntl(file->fil_desc, F_SETFL, control) == -1)
+		{
+			ERR_post(isc_io_error,
+					 isc_arg_string, "fcntl() SYNC/DIRECT",
+					 isc_arg_cstring, file->fil_length,
+					 ERR_string(file->fil_string, file->fil_length), isc_arg_gds,
+					 isc_io_access_err, isc_arg_unix, errno, 0);
 		}
-		else {
-			file->fil_flags &= ~FIL_force_write;
+#else //FCNTL_BROKEN
+		maybe_close_file(file->fil_desc);
+		file->fil_desc = openFile(file->fil_string, forcedWrites, file->fil_flags & FIL_readonly);
+		if (file->fil_desc == -1)
+		{
+			ERR_post(isc_io_error, isc_arg_string, "re open() for SYNC/DIRECT",
+					 isc_arg_cstring, file->fil_length, ERR_string(file->fil_string, file->fil_length),
+					 isc_arg_gds, isc_io_open_err, isc_arg_unix, errno, 0);
 		}
+#endif //FCNTL_BROKEN
+
+		file->fil_flags &= ~FIL_force_write;
+		file->fil_flags |= (forcedWrites ? FIL_force_write : 0);
 	}
 #endif
 }
@@ -402,7 +456,7 @@ void PIO_header(Database* dbb, SCHAR * address, int length)
  *
  **************************************/
 	int i;
-	UINT64 bytes;
+	FB_UINT64 bytes;
 
 	jrd_file* file = dbb->dbb_file;
 
@@ -426,10 +480,10 @@ void PIO_header(Database* dbb, SCHAR * address, int length)
 
 #ifdef PREAD_PWRITE
 			if ((bytes = pread(file->fil_desc, spare_buffer, length, 0)) ==
-				(UINT64) -1) {
+				(FB_UINT64) -1) {
 #else
 			if ((bytes = read(file->fil_desc, spare_buffer, length)) == 
-				(UINT64) -1) {
+				(FB_UINT64) -1) {
 				THD_IO_MUTEX_UNLOCK(file->fil_mutex);
 #endif
 				if (SYSCALL_INTERRUPTED(errno))
@@ -443,9 +497,9 @@ void PIO_header(Database* dbb, SCHAR * address, int length)
 		else
 #endif /* ISC_DATABASE_ENCRYPTION */
 #ifdef PREAD_PWRITE
-		if ((bytes = pread(file->fil_desc, address, length, 0)) == (UINT64) -1) {
+		if ((bytes = pread(file->fil_desc, address, length, 0)) == (FB_UINT64) -1) {
 #else
-		if ((bytes = read(file->fil_desc, address, length)) == (UINT64) -1) {
+		if ((bytes = read(file->fil_desc, address, length)) == (FB_UINT64) -1) {
 			THD_IO_MUTEX_UNLOCK(file->fil_mutex);
 #endif
 			if (SYSCALL_INTERRUPTED(errno))
@@ -503,7 +557,7 @@ SLONG PIO_max_alloc(Database* dbb)
 		unix_error("fstat", file, isc_io_access_err, 0);
 	}
 
-	UINT64 length = statistics.st_size;
+	FB_UINT64 length = statistics.st_size;
 
 /****
 #ifndef sun
@@ -547,7 +601,7 @@ SLONG PIO_act_alloc(Database* dbb)
 			unix_error("fstat", file, isc_io_access_err, 0);
 		}
 
-		UINT64 length = statistics.st_size;
+		FB_UINT64 length = statistics.st_size;
 
 		tot_pages += (length + dbb->dbb_page_size - 1) / dbb->dbb_page_size;
 	}
@@ -556,6 +610,8 @@ SLONG PIO_act_alloc(Database* dbb)
 }
 
 
+
+
 jrd_file* PIO_open(Database* dbb,
 			 const Firebird::PathName& string,
 			 bool trace_flag,
@@ -574,30 +630,16 @@ jrd_file* PIO_open(Database* dbb,
  *	the connection to communication with a page/lock server.
  *
  **************************************/
-	int desc, flag;
+	bool readOnly = false;
 	const TEXT* ptr = (string.hasData() ? string : file_name).c_str();
-
-#ifdef SUPERSERVER_V2
-	flag = SYNC | O_RDWR | O_BINARY;
-#else
-	flag = O_RDWR | O_BINARY;
-#endif
-
-	for (int i = 0; i < IO_RETRY; i++)
-	{
-		if ((desc = open(ptr, flag)) != -1)
-			break;
-		if (!SYSCALL_INTERRUPTED(errno))
-			break;
-	}
+	int desc = openFile(ptr, false, false);
 
 	if (desc == -1) {
 		/* Try opening the database file in ReadOnly mode. The database file could
 		 * be on a RO medium (CD-ROM etc.). If this fileopen fails, return error.
 		 */
-		flag &= ~O_RDWR;
-		flag |= O_RDONLY;
-		if ((desc = open(ptr, flag)) == -1) {
+		desc = openFile(ptr, false, true);
+		if (desc == -1) {
 			ERR_post(isc_io_error,
 					 isc_arg_string, "open",
 					 isc_arg_cstring, file_name.length(), ERR_cstring(file_name),
@@ -611,6 +653,7 @@ jrd_file* PIO_open(Database* dbb,
 			 */
 			if (!dbb->dbb_file)
 				dbb->dbb_flags |= DBB_being_opened_read_only;
+			readOnly = true;
 		}
 	}
 
@@ -619,7 +662,7 @@ jrd_file* PIO_open(Database* dbb,
 	 * mode. Check if it is a special file (i.e. raw block device) and if a
 	 * valid database is on it. If not, return an error.
 	 */
-	if (raw_devices_check_file(file_name)
+	if (PIO_on_raw_device(file_name)
 		&& !raw_devices_validate_database(desc, file_name))
 	{
 		ERR_post (isc_io_error,
@@ -634,6 +677,8 @@ jrd_file* PIO_open(Database* dbb,
 	jrd_file *file;
 	try {
 		file = setup_file(dbb, string, desc);
+		if (readOnly)
+			file->fil_flags |= FIL_readonly;
 	} catch(const std::exception&) {
 		close(desc);
 		throw;
@@ -655,7 +700,7 @@ bool PIO_read(jrd_file* file, BufferDesc* bdb, Ods::pag* page, ISC_STATUS* statu
  *
  **************************************/
 	int i;
-	UINT64 bytes, offset;
+	FB_UINT64 bytes, offset;
 
 	SignalInhibit siHolder;
 
@@ -663,7 +708,7 @@ bool PIO_read(jrd_file* file, BufferDesc* bdb, Ods::pag* page, ISC_STATUS* statu
 		return unix_error("read", file, isc_io_read_err, status_vector);
 
 	Database* dbb = bdb->bdb_dbb;
-	const UINT64 size = dbb->dbb_page_size;
+	const FB_UINT64 size = dbb->dbb_page_size;
 
 #ifdef ISC_DATABASE_ENCRYPTION
 	if (dbb->dbb_encrypt_key) {
@@ -748,7 +793,7 @@ bool PIO_write(jrd_file* file, BufferDesc* bdb, Ods::pag* page, ISC_STATUS* stat
  **************************************/
 	int i;
 	SLONG bytes;
-    UINT64 offset;
+    FB_UINT64 offset;
 
 	SignalInhibit siHolder;
 
@@ -809,7 +854,7 @@ bool PIO_write(jrd_file* file, BufferDesc* bdb, Ods::pag* page, ISC_STATUS* stat
 }
 
 
-static jrd_file* seek_file(jrd_file* file, BufferDesc* bdb, UINT64* offset,
+static jrd_file* seek_file(jrd_file* file, BufferDesc* bdb, FB_UINT64* offset,
 	ISC_STATUS* status_vector)
 {
 /**************************************
@@ -843,10 +888,10 @@ static jrd_file* seek_file(jrd_file* file, BufferDesc* bdb, UINT64* offset,
 
 	page -= file->fil_min_page - file->fil_fudge;
 
-    UINT64 lseek_offset = page;
+    FB_UINT64 lseek_offset = page;
     lseek_offset *= dbb->dbb_page_size;
 
-    if (lseek_offset != (UINT64) LSEEK_OFFSET_CAST lseek_offset)
+    if (lseek_offset != (FB_UINT64) LSEEK_OFFSET_CAST lseek_offset)
 	{
 		unix_error("lseek", file, isc_io_32bit_exceeded_err, status_vector);
 		return 0;
@@ -1114,19 +1159,19 @@ int PIO_unlink (const Firebird::PathName& file_name)
  *
  **************************************/
 
-	if (raw_devices_check_file(file_name))
+	if (PIO_on_raw_device(file_name))
 		return raw_devices_unlink_database(file_name);
 	else
 		return unlink(file_name.c_str());
 }
 
 
-static bool raw_devices_check_file (
+bool PIO_on_raw_device(
 	const Firebird::PathName& file_name)
 {
 /**************************************
  *
- *	raw_devices_check_file
+ *	P I O _ o n _ r a w _ d e v i c e
  *
  **************************************
  *
