@@ -236,7 +236,7 @@ const SSHORT CLASS		= CLASS_SOLARIS_SPARC;
 #endif
 #endif
 
-#ifdef hpux
+#ifdef HPUX
 const SSHORT CLASS		= CLASS_HPUX_PA;
 #endif
 
@@ -1148,8 +1148,10 @@ void PAG_header(bool info)
 
 	if (header->hdr_flags & hdr_force_write) {
 		dbb->dbb_flags |= DBB_force_write;
-		if (!(header->hdr_flags & hdr_read_only))
-			PIO_force_write(dbb->dbb_file, true);
+		if (!(header->hdr_flags & hdr_read_only)) {
+			for (jrd_file* file = dbb->dbb_file; file; file = file->fil_next) 
+				PIO_force_write(file, true);
+		}
 	}
 
 	if (header->hdr_flags & hdr_no_reserve)
@@ -1166,7 +1168,8 @@ void PAG_header(bool info)
 
 	}
 	catch (std::exception&) {
-		// no-op, just ensure the header page will be released
+		CCH_RELEASE(tdbb, &window);
+		throw;
 	}
 
 	CCH_RELEASE(tdbb, &window);
@@ -1449,9 +1452,7 @@ void PAG_init2(USHORT shadow_number)
 			if ((shadow_number) && (!file->fil_min_page))
 				CCH_RELEASE(tdbb, &window);
 
-			for (const TEXT* p = reinterpret_cast<TEXT*>(header->hdr_data); 
-				 *p != HDR_end; 
-				 p += 2 + p[1])
+			for (const UCHAR* p = header->hdr_data; *p != HDR_end; p += 2 + p[1])
 			{
 				switch (*p) {
 				case HDR_file:
@@ -1467,8 +1468,7 @@ void PAG_init2(USHORT shadow_number)
 				case HDR_sweep_interval:
 					// CVC: Let's copy it always.
 					//if (!(dbb->dbb_flags & DBB_read_only))
-						MOVE_FAST(p + 2, &dbb->dbb_sweep_interval,
-								  sizeof(SLONG));
+						MOVE_FAST(p + 2, &dbb->dbb_sweep_interval, sizeof(SLONG));
 					break;
 				}
 			}
