@@ -95,7 +95,7 @@ const ULONG MAX_TEMPFILE_SIZE		= 1073741824;	// 1GB
 // the size of sr_bckptr in # of 32 bit longwords
 #define SIZEOF_SR_BCKPTR_IN_LONGS  (SIZEOF_SR_BCKPTR / sizeof(SLONG))
 // offset in array of pointers to back record pointer (sr_bckptr)
-#define BACK_OFFSET (-(SIZEOF_SR_BCKPTR / sizeof(SLONG*)))
+#define BACK_OFFSET (-static_cast<signed>(SIZEOF_SR_BCKPTR / sizeof(SLONG*)))
 
 #define DIFF_LONGS(a, b)         ((a) - (b))
 #define SWAP_LONGS(a, b, t)       {t = a; a = b; b = t;}
@@ -691,7 +691,7 @@ sort_context* SORT_init(ISC_STATUS* status_vector,
 			  FPTR_REJECT_DUP_CALLBACK call_back,
 			  void* user_arg,
 			  Attachment* att,
-			  UINT64 max_records)
+			  FB_UINT64 max_records)
 {
 /**************************************
  *
@@ -2479,10 +2479,9 @@ static void merge_runs(sort_context* scb, USHORT n)
 
 void inline swap(SORTP** a, SORTP** b)
 {
-	SORTP* temp;
 	((SORTP ***) (*a))[BACK_OFFSET] = b;
 	((SORTP ***) (*b))[BACK_OFFSET] = a;
-	temp = *a;
+	SORTP* temp = *a;
 	*a = *b;
 	*b = temp;
 }
@@ -2816,7 +2815,6 @@ static void sort(sort_context* scb)
  *      been requested, detect and handle them.
  *
  **************************************/
-	SORTP* temp;
 
 	// Check out the engine
 
