@@ -214,25 +214,16 @@ rem_port* XNET_analyze(Firebird::PathName& file_name,
 
 	// Pick up some user identification information
 
-	TEXT buffer[BUFFER_TINY];
-	TEXT *p;
+	Firebird::string buffer;
 	Firebird::ClumpletWriter user_id(Firebird::ClumpletReader::UnTagged, MAX_DPB_SIZE);
 
-	ISC_get_user(buffer, 0, 0, 0, 0, 0, 0);
-	for (p = buffer; *p; p++) {
-		if (*p >= 'A' && *p <= 'Z') {
-			*p = *p - 'A' + 'a';
-		}
-	}
-	user_id.insertString(CNCT_user, buffer, strlen(buffer));
+	ISC_get_user(&buffer, 0, 0, 0);
+	buffer.lower();
+	user_id.insertString(CNCT_user, buffer);
 
-	ISC_get_host(buffer, sizeof(buffer));
-	for (p = buffer; *p; p++) {
-		if (*p >= 'A' && *p <= 'Z') {
-			*p = *p - 'A' + 'a';
-		}
-	}
-	user_id.insertString(CNCT_host, buffer, strlen(buffer));
+	ISC_get_host(buffer);
+	buffer.lower();
+	user_id.insertString(CNCT_host, buffer);
 
 	if (uv_flag) {
 		user_id.insertTag(CNCT_user_verification);
@@ -760,11 +751,11 @@ static rem_port* aux_connect(rem_port* port, PACKET* packet, t_event_ast ast)
 
 		// send events channel
 		xps->xps_channels[XPS_CHANNEL_C2S_EVENTS].xch_client_ptr =
-			((UCHAR *) xpm->xpm_address + sizeof(struct xps));
+			((UCHAR *) xcc->xcc_mapped_addr + sizeof(struct xps));
 
 		// receive events channel
 		xps->xps_channels[XPS_CHANNEL_S2C_EVENTS].xch_client_ptr =
-			((UCHAR *) xpm->xpm_address + sizeof(struct xps) + (XNET_EVENT_SPACE));
+			((UCHAR *) xcc->xcc_mapped_addr + sizeof(struct xps) + (XNET_EVENT_SPACE));
 
 		xcc->xcc_send_channel = &xps->xps_channels[XPS_CHANNEL_C2S_EVENTS];		
 		xcc->xcc_recv_channel = &xps->xps_channels[XPS_CHANNEL_S2C_EVENTS];
@@ -894,11 +885,11 @@ static rem_port* aux_request(rem_port* port, PACKET* packet)
 
 		// send events channel
 		xps->xps_channels[XPS_CHANNEL_S2C_EVENTS].xch_client_ptr =
-			((UCHAR *) xpm->xpm_address + sizeof(struct xps) + (XNET_EVENT_SPACE));
+			((UCHAR *) xcc->xcc_mapped_addr + sizeof(struct xps) + (XNET_EVENT_SPACE));
 
 		// receive events channel
 		xps->xps_channels[XPS_CHANNEL_C2S_EVENTS].xch_client_ptr =
-			((UCHAR *) xpm->xpm_address + sizeof(struct xps));
+			((UCHAR *) xcc->xcc_mapped_addr + sizeof(struct xps));
 
 		xcc->xcc_send_channel = &xps->xps_channels[XPS_CHANNEL_S2C_EVENTS];		
 		xcc->xcc_recv_channel = &xps->xps_channels[XPS_CHANNEL_C2S_EVENTS];
